aboutsummaryrefslogtreecommitdiffhomepage
path: root/src/test/java/com/google/devtools/build/lib/testutil/FoundationTestCase.java
diff options
context:
space:
mode:
authorGravatar Ulf Adams <ulfjack@google.com>2015-02-25 15:39:06 +0000
committerGravatar Han-Wen Nienhuys <hanwen@google.com>2015-02-25 15:39:06 +0000
commit53b15a4c104b7f8853ddef54a73d28aa9c695089 (patch)
tree62d9a7b5571a79a5b92d266775c987125eed1e24 /src/test/java/com/google/devtools/build/lib/testutil/FoundationTestCase.java
parente7e30f43db1944bfac3d649271cdeec2f37c8132 (diff)
Remove ChattyAssertsTestCase. Use static imports, move the code down the
tree, rewrite most uses of assertPresence. This is a small step towards migrating the tests to JUnit 4. Depending on inheritance for the assert* methods is not recommended, and the (old) Asserts class is deprecated in JUnit 4. Sorry, there was no good way to do this piecemeal. -- MOS_MIGRATED_REVID=87154212
Diffstat (limited to 'src/test/java/com/google/devtools/build/lib/testutil/FoundationTestCase.java')
-rw-r--r--src/test/java/com/google/devtools/build/lib/testutil/FoundationTestCase.java8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/test/java/com/google/devtools/build/lib/testutil/FoundationTestCase.java b/src/test/java/com/google/devtools/build/lib/testutil/FoundationTestCase.java
index 3302d33f7f..d519e421d6 100644
--- a/src/test/java/com/google/devtools/build/lib/testutil/FoundationTestCase.java
+++ b/src/test/java/com/google/devtools/build/lib/testutil/FoundationTestCase.java
@@ -24,6 +24,8 @@ import com.google.devtools.build.lib.vfs.FileSystem;
import com.google.devtools.build.lib.vfs.Path;
import com.google.devtools.build.lib.vfs.inmemoryfs.InMemoryFileSystem;
+import junit.framework.TestCase;
+
import java.io.File;
import java.io.IOException;
import java.nio.charset.Charset;
@@ -31,10 +33,10 @@ import java.util.List;
import java.util.Set;
/**
* This is a specialization of {@link ChattyAssertsTestCase} that's useful for
* implementing tests of the "foundation" library.
*/
-public abstract class FoundationTestCase extends ChattyAssertsTestCase {
+public abstract class FoundationTestCase extends TestCase {
protected Path rootDirectory;
@@ -31,10 +33,10 @@ import java.util.List;
import java.util.Set;
/**
- * This is a specialization of {@link ChattyAssertsTestCase} that's useful for
- * implementing tests of the "foundation" library.
+ * This is a specialization of {@link TestCase} that's useful for implementing tests of the
+ * "foundation" library.
*/